﻿import '@syncfusion/ej2-navigations/styles/material.css';
import '@syncfusion/ej2-popups/styles/material.css';
import '@syncfusion/ej2-splitbuttons/styles/material.css';
import "@syncfusion/ej2-react-grids/styles/material.css";

import React from 'react';
import { DataManager, ODataV4Adaptor, Query } from '@syncfusion/ej2-data';
import { DialogComponent } from "@syncfusion/ej2-react-popups";
import { GridComponent, Page, Sort, ColumnsDirective, ColumnDirective, DetailRow, Inject, ForeignKey } from '@syncfusion/ej2-react-grids';
import { TabComponent } from '@syncfusion/ej2-react-navigations';




export default class ToleranceEditDialogWR extends React.Component {
    constructor(props) {
        super(props);

        const API_ROOT = window.app && window.app.env.API_URL;
		
		this.TolMeasAPI = API_ROOT + "/tolerancemeasures"
        this.TolMeasData = new DataManager({ url: this.TolMeasAPI, adaptor: new ODataV4Adaptor(), headers: [this.header] });
        this.TolMeasQuery = new Query().where('MeasureMeasureId', 'equal', props.MeasureId);

        this.AssemblyAPI = API_ROOT + "/assemblies";
        this.AssemblyData = new DataManager({ url: this.AssemblyAPI, adaptor: new ODataV4Adaptor(), headers: [this.header] });
        this.AssemblyQuery = new Query().select(['AssemblyId', 'AssemblyText']);

        this.AuditAPI = API_ROOT + "/audits";
        this.AuditData = new DataManager({ url: this.AuditAPI, adaptor: new ODataV4Adaptor(), headers: [this.header] });

		
		
		this.AuditChildGrid = {
            dataSource: this.AuditData,
            queryString: 'AuditSequenceSequenceId',

            allowPaging: true,
            columns: [
                { field: 'AssemblyId', headerText: 'Assembly', width: '350', dataSource: this.AssemblyData, query: this.AssemblyQuery, foreignKeyValue:'AssemblyText' },
                { field: 'AuditSequenceSequenceId', visible: false, isPrimaryKey: true },
                { field: 'AuditAuditId', visible: false, isPrimaryKey: true },
                { field: 'AuditLaps', headerText: 'Laps' },
                { field: 'Priority', headerText: 'Priority' },
            ],

            load() {
                var str = 'SequenceSequenceId';
                this.parentDetails.parentKeyFieldValue = this.parentDetails.parentRowData[str];
            },
        };
        
    }


    render() {
        return (
            <div>
                <DialogComponent
                    height={1000}
                    width="90%"
                    showCloseIcon={true}
                    isModal={true}
                    header={"Edit Tolerance for measure: "}
                    ref={d => this.dialog = d}
                    allowDragging={true}
                >
                    <div className="content">
                        
                        <div className="col-xs-12">
                            <TabComponent>
                                <div className="e-tab-header">
                                    <div> Sequence Usage </div>
                                    <div> Measure Tolerances </div>
                                </div>
                                <div className="e-content">
                                    <div>
                                        TEXT
                                    </div>
                                    <div>
										<GridComponent
											allowPaging={true}
											allowSorting={true}
											width="100%"
											dataSource={this.TolMeasData}
											query={this.TolMeasQuery}
											childGrid={this.AuditChildGrid}
											ref={(g) => this.grid = g}
										>

											<ColumnsDirective>
												<ColumnDirective field='ToleranceToleranceId' headerText="Tolerance ID" isPrimaryKey={true} />
												<ColumnDirective field='SequenceSequenceId' allowEditing={false} headerText="Sequence ID" isPrimaryKey={true} />
												<ColumnDirective field='MeasureMeasureId' visible={false} isPrimaryKey={true} />
												<ColumnDirective field='ToleranceLow' headerText="Low" />
												<ColumnDirective field='ToleranceNominal' headerText="Nominal" />
												<ColumnDirective field='ToleranceHigh' headerText="High" />

											</ColumnsDirective>

											<Inject services={[Page, ForeignKey, Sort, DetailRow]} />
										</GridComponent>
                                    </div>
                                </div>
                            </TabComponent>
                        </div>
                    </div>


                </DialogComponent>
                <div>
                    { this.Dialogs }
                </div>
            </div>
        );
    }
}